import * as THREE from 'three';
import CameraControls from 'camera-controls';
import ModelData from './entity/ModelData';
import Mouse, { TransformModel, TransformMouseModel } from './mouse/Mouse';
import HandlerConstant from './constant/HandlerConstant';
import HandlerFactory from './handler/HandlerFactory';
declare enum LIGHTTYPE {
    AmbientLight = "AmbientLight",
    PointLight = "PointLight",
    DirectionalLight = "DirectionalLight",
    SpotLight = "SpotLight"
}
declare type InitialSceneParams = {
    containerId: string;
    cameraOption?: any;
    backgroundColor?: any;
    webglRebderOptions?: any;
};
declare type ViewerProps = {
    /**
    * @description       viewer容器挂载的Id
    */
    containerId: string;
    backgroundColor: string;
    defaultLightType?: LIGHTTYPE;
    labelRender?: boolean;
    transformControl?: boolean;
    axesShow?: number;
    initialSceneParams?: any;
    contextmenuEvent?: Function;
    keyCameraControl?: boolean;
};
export default class Viewer {
    props: ViewerProps;
    modelMap: Map<string, any>;
    meshList: THREE.Mesh[];
    camera: any;
    scene: THREE.Scene;
    lightMap: Map<string, THREE.Light>;
    renderer: THREE.WebGLRenderer;
    labelRenderer: any;
    cameraControls: CameraControls;
    clock: THREE.Clock;
    viewerModel: THREE.Object3D;
    defaultLight: THREE.Light;
    mouse: Mouse;
    containerId: string;
    autorotate: any;
    current_frame: any;
    transformControls: any;
    handlerFactory: HandlerFactory;
    updated: boolean;
    gridX: any;
    gridY: any;
    gridZ: any;
    constructor(props: ViewerProps);
    /**
     * 创建three场景，根据相关参数设定相机，光照点初始位置
     */
    initialScene: (initialSceneParams: InitialSceneParams) => void;
    initCamera: (cameraOption: {
        position: any;
        fov: number;
        aspect: number;
        near: number;
        far: number;
    }, domWidth: number, domHeight: number) => THREE.PerspectiveCamera;
    addEventListener: () => void;
    updateViewerByWithAndHeight: (width: number, height: number) => void;
    /**
     * 设置默认光源
     */
    applyDefaultLight: () => void;
    updateLightIntensity: (value: number) => void;
    /**
     * 只能修改默认的光源位置
     */
    updateLightPosition: (index: string, position: {
        x: number;
        y: number;
        z: number;
    }) => void;
    /**
     * 添加光源
     */
    addLight: ({ coordinate, index, type, intensity, color }: {
        type: string;
        index: string;
        coordinate?: {
            x: number;
            y: number;
            z: number;
        };
        intensity?: any;
        color?: any;
    }) => void;
    updateLookPostion: ({ x, y, z, }: {
        x: any;
        y: any;
        z: any;
    }) => void;
    animation: () => void;
    updateAutorotate: (coor: any) => void;
    /**
     * 获取相机
     */
    getCamera: () => any;
    /**
     * 获取相机控制器
     */
    getCameraControll: () => CameraControls;
    addModelToViewer: (modelData: ModelData, options?: any, isForceAdd?: boolean) => void;
    handleGiftiFile: (file: File, name: string, options?: any) => Promise<void>;
    /**
     * 处理强度文件，需要指定使用的模型索引值，isNoumenon标志是重创建还是复制模式
     */
    handleGiftiIntensityFile: (file: any, name: string, options?: any) => Promise<void>;
    handleModelJson: (data: {
        indices: any;
        vertices: any;
        normals: any;
        intensityValues: any;
        colorMap: any;
    }, name: any, options: any) => void;
    handleNodeJson: (data: any, name: any, options: any) => void;
    handleContourJson: (data: any, name: any, options: any) => void;
    handleModelByFile: (file: File, { name, handlerTypes, options, initialHandledResult }: {
        name: string;
        handlerTypes: Array<HandlerConstant>;
        options: any;
        initialHandledResult?: any;
    }) => Promise<unknown>;
    handlerData: (data: any, options: any, handlerTypes: Array<HandlerConstant>, initialHandledResult?: any) => any;
    /**
     * 修改透明度
     * 默认修改模型所有的透明度，可以指定index索引值，改值是加载模型是指定的index
     * @param alpha
     * @param options
     */
    updateOpacity: (alpha: number, options: {
        name: string;
    }) => void;
    /**
     * 是否显示线框模型
     * @param isWireframe
     * @param shape_name
     */
    updateWireframe: (isWireframe: boolean, options: {
        name: string;
    }) => void;
    showBoundBox: (boundBoxIsShow: boolean, options: {
        name: string;
    }) => void;
    setVisitable: (isVisible: boolean, options: {
        name: string;
    }) => void;
    toggleVisitable: (name: string) => void;
    updateNormalHelpStatus: (status: boolean, options: {
        name: string;
    }) => void;
    updateColorMap: (colorMap: any, options: {
        name: string;
    }) => void;
    updateImagePosRange: (min: number, max: number, options: {
        name: string;
    }) => void;
    updateImageNegRange: (min: number, max: number, options: {
        name: string;
    }) => void;
    updateGrid: (coor: {
        x: number;
        y: number;
        z: number;
    }) => void;
    clear: () => void;
    arrowInit: (modelData: ModelData) => void;
    gridInit: (mesh: any) => void;
    getColorAxes: () => any;
    /**
     * 修改鼠标运动方式
     */
    updateMouseModel: (model: TransformMouseModel) => void;
    /**
 * 修改鼠标运动方式
 */
    updateTransformMouseModel: (model: TransformModel) => void;
    remove: (name: string, options?: any) => void;
    getObjectPosition: (name: string) => {
        position: THREE.Vector3;
        quaternion: THREE.Quaternion;
        center: any;
        radius: any;
        matrix: THREE.Matrix4;
    };
    exportObjectByName: (name: string) => void;
    gridHelp: (horizontal_from: any, horizontal_to: any, x1: any, x2: any, horizontal_color: any, vertical_from: any, vertical_to: any, z1: any, z2: any, step: any) => THREE.LineSegments<THREE.BufferGeometry, THREE.LineBasicMaterial>;
    pick: (x: any, y: any, opacity_threshold: any) => any;
    setTransformControlMeshByKey: ({ name }: {
        name: any;
    }) => void;
    setTransformControlsEnable: (isEnable: boolean) => void;
}
export {};
